@@ -58,6 +58,13 @@ def timestamp_toString(stamp: int) -> str:
     """
     return time.strftime("%Y-%m-%d", time.localtime(stamp))
 
+def ts_toStr_det(stamp: int) -> str:
+    """
+    把时间戳转成字符串形式精确到秒
+    :param stamp: 1577808000
+    :return: '2020-01-01'
+    """
+    return time.strftime("%Y-%m-%d", time.localtime(stamp))
 
 def datetime_toTimestamp(dateTime):
     """
